#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   gi-harfbuzz
version:                0.0.10
visibility:             public
id:                     gi-harfbuzz-0.0.10-J1ooyjBqLfQ8yooqAWyR0a
key:                    gi-harfbuzz-0.0.10-J1ooyjBqLfQ8yooqAWyR0a
license:                LGPL-2.1-only
maintainer:             Iñaki García Etxebarria
author:                 Iñaki García Etxebarria
homepage:               https://github.com/haskell-gi/haskell-gi
synopsis:               HarfBuzz bindings
description:            Bindings for HarfBuzz, autogenerated by haskell-gi.
category:               Bindings
abi:                    26242c5bd73439e8a8f2beaeebecbbb1
exposed:                True
exposed-modules:
    GI.HarfBuzz GI.HarfBuzz.Callbacks GI.HarfBuzz.Config
    GI.HarfBuzz.Constants GI.HarfBuzz.Enums GI.HarfBuzz.Flags
    GI.HarfBuzz.Functions GI.HarfBuzz.Structs
    GI.HarfBuzz.Structs.AatLayoutFeatureSelectorInfoT
    GI.HarfBuzz.Structs.BlobT GI.HarfBuzz.Structs.BufferT
    GI.HarfBuzz.Structs.ColorLineT GI.HarfBuzz.Structs.ColorStopT
    GI.HarfBuzz.Structs.DrawFuncsT GI.HarfBuzz.Structs.DrawStateT
    GI.HarfBuzz.Structs.FaceT GI.HarfBuzz.Structs.FeatureT
    GI.HarfBuzz.Structs.FontExtentsT GI.HarfBuzz.Structs.FontFuncsT
    GI.HarfBuzz.Structs.FontT GI.HarfBuzz.Structs.GlyphExtentsT
    GI.HarfBuzz.Structs.GlyphInfoT GI.HarfBuzz.Structs.GlyphPositionT
    GI.HarfBuzz.Structs.LanguageT GI.HarfBuzz.Structs.MapT
    GI.HarfBuzz.Structs.OtColorLayerT
    GI.HarfBuzz.Structs.OtMathGlyphPartT
    GI.HarfBuzz.Structs.OtMathGlyphVariantT
    GI.HarfBuzz.Structs.OtMathKernEntryT
    GI.HarfBuzz.Structs.OtNameEntryT GI.HarfBuzz.Structs.OtVarAxisInfoT
    GI.HarfBuzz.Structs.OtVarAxisT GI.HarfBuzz.Structs.PaintFuncsT
    GI.HarfBuzz.Structs.SegmentPropertiesT GI.HarfBuzz.Structs.SetT
    GI.HarfBuzz.Structs.ShapePlanT GI.HarfBuzz.Structs.UnicodeFuncsT
    GI.HarfBuzz.Structs.UserDataKeyT GI.HarfBuzz.Structs.VariationT
    GI.HarfBuzz.Unions GI.HarfBuzz.Unions.VarIntT
    GI.HarfBuzz.Unions.VarNumT

import-dirs:            /usr/lib/ghc-9.6.6/site-local/gi-harfbuzz-0.0.10
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/gi-harfbuzz-0.0.10 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/gi-harfbuzz-0.0.10 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-gi-harfbuzz
hs-libraries:           HSgi-harfbuzz-0.0.10-J1ooyjBqLfQ8yooqAWyR0a
extra-libraries:        harfbuzz-gobject harfbuzz gobject-2.0 glib-2.0
extra-libraries-static:
    harfbuzz-gobject harfbuzz m freetype dl bz2 png16 m m z brotlidec
    brotlicommon graphite2 gobject-2.0 glib-2.0 atomic m
    sysprof-capture-4 pcre2-8 pthread ffi

include-dirs:
    /usr/include/harfbuzz /usr/include/freetype2 /usr/include
    /usr/include/libpng16 /usr/include/glib-2.0
    /usr/lib/glib-2.0/include /usr/include/sysprof-6

depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    gi-freetype2-2.0.5-C77Obrqm4ZI5Clit46b52W
    gi-glib-2.0.30-FejhVcYM7fID8sxSnazhRe
    gi-gobject-2.0.31-BmSKunruCgzyGlfjkMWF9
    haskell-gi-0.26.17-3KJumM1XU8AkHOk3X5Pcn
    haskell-gi-base-0.26.9-DWjNTqMCnmO6mDRH5jgSPC
    haskell-gi-overloading-1.0-6w3IXGDooXgu3RA2LfTuf text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:     /usr/share/doc/haskell-gi-harfbuzz/html/gi-harfbuzz.haddock
haddock-html:           /usr/share/doc/haskell-gi-harfbuzz/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

